@@ -1,6 +1,5 @@
 /*
  * entryobj.c
- * $Id: entryobj.c 117407 2014-02-25 18:28:14Z jmr@macports.org $
  *
  * Copyright (c) 2007 Chris Pickel <sfiera@macports.org>
  * All rights reserved.
@@ -42,7 +41,6 @@
 const char* entry_props[] = {
     "name",
     "portfile",
-    "url",
     "location",
     "epoch",
     "version",
@@ -419,7 +417,6 @@ static entry_obj_cmd_type entry_cmds[] = {
     /* keys */
     { "name", entry_obj_prop },
     { "portfile", entry_obj_prop },
-    { "url", entry_obj_prop },
     { "location", entry_obj_prop },
     { "epoch", entry_obj_prop },
     { "version", entry_obj_prop },
